package cn.estsh.i3plus.core.apiservice.controller.busi;

import cn.estsh.i3plus.core.api.iservice.busi.ISysTableTemplateService;
import cn.estsh.i3plus.platform.common.util.PlatformConstWords;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.platform.bean.SysTableTemplate;
import cn.estsh.impp.framework.boot.auth.AuthUtil;
import cn.estsh.impp.framework.boot.util.ResultBean;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.util.ObjectUtils;
import org.springframework.web.bind.annotation.*;

/**
 * @author ns
 * @create 2022/3/17 0017 上午 11:39
 */
@RestController
@RequestMapping(PlatformConstWords.BASE_URL + "/sys-table-template")
@Api(tags = "前端表格模板")
public class SysTableTemplateController {

    private ISysTableTemplateService iSysTableTemplateService;

    public SysTableTemplateController(ISysTableTemplateService sysTableTemplateService) {
        this.iSysTableTemplateService = sysTableTemplateService;
    }

    @ApiOperation("新增系统模板")
    @PostMapping("/insert")
    public ResultBean insertSysTableTemplate(SysTableTemplate sysTableTemplate) throws NoSuchFieldException {
        //条件验证
        ValidatorBean.beginValid(sysTableTemplate)
                .notNull("softType", sysTableTemplate.getSoftType())
                .notNull("templateData", sysTableTemplate.getTemplateData())
                .notNull("page", sysTableTemplate.getPage())
                .notNull("templateType", sysTableTemplate.getTemplateType());
        if (CommonEnumUtil.USER_TYPE.ADMIN.equals(AuthUtil.getUserType())) {
            return ResultBean.success().setResultObject(iSysTableTemplateService.insertSysTableTemplate((sysTableTemplate)));
        }
        return ResultBean.fail("当前用户不是管理员，不能新增");

    }

    @ApiOperation("修改系统模板")
    @PutMapping("/update")
    public ResultBean updateSysTableTemplate(SysTableTemplate sysTableTemplate) throws NoSuchFieldException {
        //条件验证
        ValidatorBean.beginValid(sysTableTemplate)
                .notNull("id", sysTableTemplate.getId());
        if (CommonEnumUtil.USER_TYPE.ADMIN.equals(AuthUtil.getUserType())) {
            return ResultBean.success().setResultObject(iSysTableTemplateService.updateSysTableTemplate((sysTableTemplate)));
        }
        return ResultBean.fail("当前用户不是管理员，不能修改");
    }

    @ApiOperation("修改系统模板,如果不存在则新增模板")
    @PutMapping("/putIfAbsent")
    public ResultBean putIfSysTableTemplateAbsent(SysTableTemplate sysTableTemplate) throws NoSuchFieldException {
        //条件验证

        if (!CommonEnumUtil.USER_TYPE.ADMIN.equals(AuthUtil.getUserType())) {
           return ResultBean.fail("当前用户不是管理员，不能修改");
        }
        ValidatorBean validatorBean = ValidatorBean.beginValid(sysTableTemplate);
        if (ObjectUtils.isEmpty(sysTableTemplate.getId())) {
            validatorBean
                    .notNull("softType", sysTableTemplate.getSoftType())
                    .notNull("templateData", sysTableTemplate.getTemplateData())
                    .notNull("page", sysTableTemplate.getPage())
                    .notNull("templateType", sysTableTemplate.getTemplateType());
            return ResultBean.success().setResultObject(iSysTableTemplateService.insertSysTableTemplate((sysTableTemplate)));
        }
        return ResultBean.success().setResultObject(iSysTableTemplateService.updateSysTableTemplate((sysTableTemplate)));
    }

    @ApiOperation("查询系统模板")
    @GetMapping("/find")
    public ResultBean findSysTableTemplate(SysTableTemplate sysTableTemplate) throws NoSuchFieldException {
        if (ObjectUtils.isEmpty(sysTableTemplate)) {
            return ResultBean.fail("查询条件不能为空");
        }
        if (ObjectUtils.isEmpty(sysTableTemplate.getId())
                && ObjectUtils.isEmpty(sysTableTemplate.getPage())
                && ObjectUtils.isEmpty(sysTableTemplate.getSoftType())
                && ObjectUtils.isEmpty(sysTableTemplate.getTemplateType())) {
            return ResultBean.fail("查询条件不能为空");
        }
        return ResultBean.success().setResultObject(iSysTableTemplateService.findSysTableTemplate((sysTableTemplate)));

    }


    @ApiOperation("分页查询系统模板")
    @GetMapping("/findBypage")
    public ResultBean findSysTableTemplateByPage(SysTableTemplate sysTableTemplate, Pager pager) throws NoSuchFieldException {
        if (ObjectUtils.isEmpty(pager)) {
            pager = Pager.defaultPager();
        }
        return ResultBean.success().setResultObject(iSysTableTemplateService.findSysTableTemplateByPage(sysTableTemplate, pager));

    }

}
